function x=nula(tol,iterM)
%Funkcija x=nula(tol,iterM) odredjuje nulu tablicno zadate
%funkcije u tablica.m koriscenjem metode secice. Za prve dve
%iteracije koristi krajeve intervala na kome se resava jednacina.
%
%
%Ulazni argumenti su:
%     tol - tacnost
%     iterM - maksimalni dozvoljeni broj iteracija
%Izlazni argumenti su:
%     x - nula tablicno zadate funkcije
%

tablica;
n=length(X);
koef=Lagranz(); 
f=@(x)polyval(koef,x);  
Y=zeros(1,iterM);
iter=0;
x0=X(1); %Xn-1
x1=X(n);%Xn
while iter<iterM
    x2=x1-(f(x1)/(f(x0)-f(x1)))*(x0-x1); 
    iter=iter+1; 
    Y(iter)=f(x2);
    greska=abs(x2-x1);
     if greska <tol
           break;
    end
    x0=x1;
    x1=x2;
end
I=1:iter;
Y=Y(1:iter);
if iter==iterM && greska<tol
    disp('Zadovoljena je tacnost i dostignut je maksimalan broj iteracija.');
else if iter==iterM
    disp('Zadovoljen je maksimalan broj iteracija.');
    else 
        disp('Zadovoljena je tacnost tol')
    end
end
x=x2;
disp(['I: ' num2str(I,5)])
disp(['Y: ' num2str(Y,5)])